@@ -47,6 +47,10 @@ type AccountView struct {
 	// Check-mail ticker
 	ticker       *time.Ticker
 	checkingMail bool
+	// Indicates whether the account has a new mail: this is a mail that has
+	// arrived since the account tab was last focused (if it's currently
+	// focused, the flag is not set).
+	hasNew bool
 }
 
 func (acct *AccountView) UiConfig() *config.UIConfig {
@@ -190,6 +194,8 @@ func (acct *AccountView) MouseEvent(localX int, localY int, event vaxis.Event) {
 
 func (acct *AccountView) Focus(focus bool) {
 	// TODO: Unfocus children I guess
+	acct.hasNew = false
+	acct.setTitle()
 }
 
 func (acct *AccountView) Directories() DirectoryLister {
@@ -278,6 +284,7 @@ func (acct *AccountView) newStore(name string) *lib.MessageStore {
 				ForFolder(name)
 		},
 		func(msg *models.MessageInfo) {
+			acct.worker.Debugf("Invoking mail-received hook")
 			err := hooks.RunHook(&hooks.MailReceived{
 				Account: acct.Name(),
 				Backend: backend,
@@ -290,10 +297,16 @@ func (acct *AccountView) newStore(name string) *lib.MessageStore {
 				PushError(msg)
 			}
 		}, func() {
+			acct.worker.Debugf("Invoking directory-change hook")
 			if uiConf.NewMessageBell {
 				aerc.Beep()
 			}
+			// Set a new message indicator.
+			if aerc.SelectedTab() != acct.tab {
+				acct.hasNew = true
+			}
 		}, func() {
+			acct.worker.Debugf("Invoking mail-deleted hook")
 			err := hooks.RunHook(&hooks.MailDeleted{
 				Account: acct.Name(),
 				Backend: backend,
@@ -305,6 +318,7 @@ func (acct *AccountView) newStore(name string) *lib.MessageStore {
 				PushError(msg)
 			}
 		}, func(dest string) {
+			acct.worker.Debugf("Invoking mail-added hook")
 			err := hooks.RunHook(&hooks.MailAdded{
 				Account: acct.Name(),
 				Backend: backend,
@@ -315,18 +329,21 @@ func (acct *AccountView) newStore(name string) *lib.MessageStore {
 				msg := fmt.Sprintf("mail-added hook: %s", err)
 				PushError(msg)
 			}
-		}, func(add []string, remove []string) {
+		}, func(add []string, remove []string, toggle []string) {
+			acct.worker.Debugf("Invoking tag-modified hook")
 			err := hooks.RunHook(&hooks.TagModified{
 				Account: acct.Name(),
 				Backend: backend,
 				Add:     add,
 				Remove:  remove,
+				Toggle:  toggle,
 			})
 			if err != nil {
 				msg := fmt.Sprintf("tag-modified hook: %s", err)
 				PushError(msg)
 			}
 		}, func(flagname string) {
+			acct.worker.Debugf("Invoking flag-changed hook")
 			err := hooks.RunHook(&hooks.FlagChanged{
 				Account:  acct.Name(),
 				Backend:  backend,
@@ -375,7 +392,7 @@ func (acct *AccountView) onMessage(msg types.WorkerMessage) {
 			acct.SetStatus(state.ConnectionActivity("Listing mailboxes..."))
 			log.Infof("[%s] connected.", acct.acct.Name)
 			acct.SetStatus(state.SetConnected(true))
-			log.Tracef("Listing mailboxes...")
+			log.Tracef("[%s] Listing mailboxes...", acct.acct.Name)
 			acct.worker.PostAction(&types.ListDirectories{}, nil)
 		case *types.Disconnect:
 			acct.dirlist.ClearList()
@@ -466,19 +483,44 @@ func (acct *AccountView) onMessage(msg types.WorkerMessage) {
 		}
 	case *types.MessageInfo:
 		if store, ok := acct.dirlist.SelectedMsgStore(); ok {
+			if msg.Unsolicited || msg.ReplaceFlags {
+				// This is a server generated message update, e.g. a
+				// notification that a message has changed (this will happen
+				// mostly for flags according to section 2.3.1.1 alinea 4 in
+				// the IMAP4rev1 RFC), or a forced flag update.
+				// In case the store and the notification disagree on the Seen
+				// flag, trust the notification.
+				seen_in_sync := true
+				if msg_in_store, ok := store.Messages[msg.Info.Uid]; ok && msg_in_store != nil {
+					seen_in_sync = msg_in_store.Flags.Has(models.SeenFlag) ==
+						msg.Info.Flags.Has(models.SeenFlag)
+				}
+				if !seen_in_sync {
+					if dir := acct.dirlist.SelectedDirectory(); dir != nil {
+						// Our view of Unseen is out-of-sync with the server's;
+						// update it now.
+						if msg.Info.Flags.Has(models.SeenFlag) {
+							dir.Unseen -= 1
+						} else {
+							dir.Unseen += 1
+						}
+						dir.Unseen = acct.ensurePositive(dir.Unseen, "Unseen")
+					}
+				}
+			}
 			store.Update(msg)
 		}
 	case *types.MessagesDeleted:
 		if dir := acct.dirlist.SelectedDirectory(); dir != nil {
-			dir.Exists -= len(msg.Uids)
+			acct.updateDirCounts(dir.Name, msg.Uids, true)
 		}
 		if store, ok := acct.dirlist.SelectedMsgStore(); ok {
 			store.Update(msg)
 		}
 	case *types.MessagesCopied:
-		acct.updateDirCounts(msg.Destination, msg.Uids)
+		acct.updateDirCounts(msg.Destination, msg.Uids, false)
 	case *types.MessagesMoved:
-		acct.updateDirCounts(msg.Destination, msg.Uids)
+		acct.updateDirCounts(msg.Destination, msg.Uids, false)
 	case *types.LabelList:
 		acct.labels = msg.Labels
 	case *types.ConnError:
@@ -495,37 +537,66 @@ func (acct *AccountView) onMessage(msg types.WorkerMessage) {
 	acct.setTitle()
 }
 
-func (acct *AccountView) updateDirCounts(destination string, uids []models.UID) {
+func (acct *AccountView) ensurePositive(val int, name string) int {
+	if val < 0 {
+		acct.worker.Errorf("Unexpected negative value (%d) for %s", val, name)
+		return 0
+	}
+	return val
+}
+
+func (acct *AccountView) updateDirCounts(destination string, uids []models.UID, deleted bool) {
 	// Only update the destination destDir if it is initialized
 	if destDir := acct.dirlist.Directory(destination); destDir != nil {
 		var recent, unseen int
 		var accurate bool = true
-		for _, uid := range uids {
-			// Get the message from the originating store
-			msg, ok := acct.Store().Messages[uid]
-			if !ok {
-				continue
-			}
-			// If message that was not yet loaded is copied
-			if msg == nil {
-				accurate = false
-				break
-			}
-			seen := msg.Flags.Has(models.SeenFlag)
-			if msg.Flags.Has(models.RecentFlag) {
-				recent++
-			}
-			if !seen {
-				unseen++
+		store := acct.Store()
+		if store == nil {
+			// This could happen for example if a disconnection happened,
+			// and we can't do anything but bail out.
+			accurate = false
+		} else {
+			for _, uid := range uids {
+				// Get the message from the originating store
+				msg, ok := store.Messages[uid]
+				if !ok {
+					continue
+				}
+				// If message that was not yet loaded is copied
+				if msg == nil {
+					accurate = false
+					break
+				}
+				if msg.Flags.Has(models.RecentFlag) {
+					recent++
+				}
+				seen := msg.Flags.Has(models.SeenFlag)
+				if !seen {
+					// If the message is unseen, the directory's current unseen
+					// count is off by one and (1) too low if the message is new,
+					// or (2) too high if the message has been deleted.
+					if !deleted {
+						unseen++
+					} else {
+						unseen--
+					}
+				}
 			}
 		}
 		if accurate {
 			destDir.Recent += recent
 			destDir.Unseen += unseen
+		}
+		if !deleted {
 			destDir.Exists += len(uids)
 		} else {
-			destDir.Exists += len(uids)
+			destDir.Exists -= len(uids)
 		}
+		destDir.Unseen = acct.ensurePositive(destDir.Unseen, "Unseen")
+		destDir.Recent = acct.ensurePositive(destDir.Recent, "Recent")
+		destDir.Exists = acct.ensurePositive(destDir.Exists, "Exists")
+	} else {
+		acct.worker.Errorf("Skipping unknown directory %s", destination)
 	}
 }
 
@@ -677,6 +748,18 @@ func (acct *AccountView) updateSplitView(msg *models.MessageInfo) {
 				case config.SPLIT_VERTICAL:
 					acct.grid.AddChild(acct.split).At(0, 2)
 				}
+				// If the user wants to, start a timer to mark the message read
+				// if it stays in the message viewer longer than the requested
+				// delay.
+				if !uiConf.AutoMarkReadInSplit {
+					return
+				}
+				acct.splitDebounce = time.AfterFunc(uiConf.AutoMarkReadInSplitDelay, func() {
+					if view == nil || view.MessageInfo() == nil || view.Store() == nil {
+						return
+					}
+					view.Store().Flag([]models.UID{view.MessageInfo().Uid}, models.SeenFlag, true, nil)
+				})
 			})
 	}
 	acct.splitDebounce = time.AfterFunc(100*time.Millisecond, func() {
@@ -695,6 +778,18 @@ func (acct *AccountView) SetSplitSize(n int) {
 	acct.splitSize = n
 }
 
+func (acct *AccountView) ToggleHeaders() {
+	config.Viewer.ShowHeaders = !config.Viewer.ShowHeaders
+	if acct.splitSize == 0 {
+		return
+	}
+	msg, err := acct.SelectedMessage()
+	if err != nil {
+		log.Debugf("split: load message error: %v", err)
+	}
+	acct.updateSplitView(msg)
+}
+
 // Split splits the message list view horizontally. The message list will be n
 // rows high. If n is 0, any existing split is removed
 func (acct *AccountView) Split(n int) {
@@ -765,6 +860,7 @@ func (acct *AccountView) setTitle() {
 	data.SetFolder(acct.Directories().SelectedDirectory())
 	data.SetRUE(acct.dirlist.List(), acct.dirlist.GetRUECount)
 	data.SetState(&acct.state)
+	data.SetHasNew(acct.hasNew)
 
 	var buf bytes.Buffer
 	err := templates.Render(acct.UiConfig().TabTitleAccount, &buf, data.Data())
