@@ -425,6 +425,32 @@ func (aerc *Aerc) Event(event vaxis.Event) bool {
 			return interactive.Event(event)
 		}
 		return false
+	case vaxis.FocusIn:
+		if focusable, ok := aerc.SelectedTabContent().(ui.Focusable); ok {
+			focusable.Focus(true)
+			return true
+		}
+		return false
+	case vaxis.FocusOut:
+		if focusable, ok := aerc.SelectedTabContent().(ui.Focusable); ok {
+			focusable.Focus(false)
+			return true
+		}
+		return false
+	case vaxis.ColorThemeUpdate:
+		// Color theme changes need to be sent to all the tabs because
+		// there may be for instance multiple open virtual terminals
+		// each running a program that needs to be made aware of the
+		// change in order to repaint itself.
+		processed := false
+		i := 0
+		for tab := aerc.tabs.Get(0); tab != nil; tab = aerc.tabs.Get(i) {
+			i++
+			if interactive, ok := tab.Content.(ui.Interactive); ok {
+				processed = interactive.Event(event) || processed
+			}
+		}
+		return processed
 	}
 	return false
 }
@@ -853,7 +879,7 @@ func (aerc *Aerc) mbox(source string) error {
 func (aerc *Aerc) CloseBackends() error {
 	var returnErr error
 	for _, acct := range aerc.accounts {
-		var raw interface{} = acct.worker.Backend
+		var raw any = acct.worker.Backend
 		c, ok := raw.(io.Closer)
 		if !ok {
 			continue
