@@ -4,7 +4,9 @@ import (
 	"bytes"
 	"context"
 	"math"
+	"path/filepath"
 	"regexp"
+	"slices"
 	"sort"
 	"time"
 
@@ -34,7 +36,7 @@ type DirectoryLister interface {
 
 	OnVirtualNode(func())
 
-	NextPrev(int)
+	NextPrev(int, bool)
 
 	CollapseFolder(string)
 	ExpandFolder(string)
@@ -104,6 +106,7 @@ func (dirlist *DirectoryList) List() []string {
 }
 
 func (dirlist *DirectoryList) ClearList() {
+	dirlist.store = lib.NewDirStore()
 	dirlist.dirs = []string{}
 }
 
@@ -118,13 +121,7 @@ func (dirlist *DirectoryList) Update(msg types.WorkerMessage) {
 			dirlist.previous = dirlist.selected
 			dirlist.selected = msg.Directory
 			dirlist.filterDirsByFoldersConfig()
-			hasSelected := false
-			for _, d := range dirlist.dirs {
-				if d == dirlist.selected {
-					hasSelected = true
-					break
-				}
-			}
+			hasSelected := slices.Contains(dirlist.dirs, dirlist.selected)
 			if !hasSelected && dirlist.selected != "" {
 				dirlist.dirs = append(dirlist.dirs, dirlist.selected)
 			}
@@ -417,7 +414,10 @@ func (dirlist *DirectoryList) Clicked(x int, y int) (string, bool) {
 	return "", false
 }
 
-func (dirlist *DirectoryList) NextPrev(delta int) {
+func (dirlist *DirectoryList) NextPrevDelta(delta int) {
+	if delta == 0 {
+		return
+	}
 	curIdx := findString(dirlist.dirs, dirlist.selecting)
 	if curIdx == len(dirlist.dirs) {
 		return
@@ -438,12 +438,28 @@ func (dirlist *DirectoryList) NextPrev(delta int) {
 	dirlist.Select(dirlist.dirs[newIdx])
 }
 
+func (dirlist *DirectoryList) NextPrev(delta int, unseen bool) {
+	if unseen {
+		ndirs := len(dirlist.dirs)
+		for range ndirs {
+			dirlist.NextPrevDelta(delta)
+			if findString(dirlist.dirs, dirlist.selecting) >= 0 {
+				if dirlist.Directory(dirlist.selecting).Unseen > 0 {
+					return
+				}
+			}
+		}
+	} else {
+		dirlist.NextPrevDelta(delta)
+	}
+}
+
 func (dirlist *DirectoryList) Next() {
-	dirlist.NextPrev(1)
+	dirlist.NextPrevDelta(1)
 }
 
 func (dirlist *DirectoryList) Prev() {
-	dirlist.NextPrev(-1)
+	dirlist.NextPrevDelta(-1)
 }
 
 func folderMatches(folder string, pattern string) bool {
@@ -470,16 +486,18 @@ func (dirlist *DirectoryList) sortDirsByFoldersSortConfig() {
 
 	sort.Slice(dirlist.dirs, func(i, j int) bool {
 		foldersSort := dirlist.acctConf.FoldersSort
-		iInFoldersSort := findString(foldersSort, dirlist.dirs[i])
-		jInFoldersSort := findString(foldersSort, dirlist.dirs[j])
-		if iInFoldersSort >= 0 && jInFoldersSort >= 0 {
-			return iInFoldersSort < jInFoldersSort
-		}
-		if iInFoldersSort >= 0 {
-			return true
-		}
-		if jInFoldersSort >= 0 {
-			return false
+		iInFoldersSort := findFirstMatchingString(foldersSort, dirlist.dirs[i])
+		jInFoldersSort := findFirstMatchingString(foldersSort, dirlist.dirs[j])
+		if iInFoldersSort != jInFoldersSort {
+			if iInFoldersSort >= 0 && jInFoldersSort >= 0 {
+				return iInFoldersSort < jInFoldersSort
+			}
+			if iInFoldersSort >= 0 {
+				return true
+			}
+			if jInFoldersSort >= 0 {
+				return false
+			}
 		}
 		return dirlist.dirs[i] < dirlist.dirs[j]
 	})
@@ -557,3 +575,13 @@ func findString(slice []string, str string) int {
 	}
 	return -1
 }
+
+func findFirstMatchingString(slice []string, str string) int {
+	for i, s := range slice {
+		matches, err := filepath.Match(s, str)
+		if err == nil && matches {
+			return i
+		}
+	}
+	return -1
+}
