@@ -1,22 +1,25 @@
 package app
 
 import (
+	"context"
+
 	"git.sr.ht/~rjarry/aerc/config"
 	"git.sr.ht/~rjarry/aerc/lib"
 	"git.sr.ht/~rjarry/aerc/lib/ui"
+	"git.sr.ht/~rjarry/go-opt/v2"
 	"git.sr.ht/~rockorager/vaxis"
 )
 
 type ExLine struct {
 	commit      func(cmd string)
 	finish      func()
-	tabcomplete func(cmd string) ([]string, string)
+	tabcomplete func(ctx context.Context, cmd string) ([]opt.Completion, string)
 	cmdHistory  lib.History
 	input       *ui.TextInput
 }
 
 func NewExLine(cmd string, commit func(cmd string), finish func(),
-	tabcomplete func(cmd string) ([]string, string),
+	tabcomplete func(ctx context.Context, cmd string) ([]opt.Completion, string),
 	cmdHistory lib.History,
 ) *ExLine {
 	input := ui.NewTextInput("", config.Ui).Prompt(":").Set(cmd)
@@ -38,7 +41,7 @@ func NewExLine(cmd string, commit func(cmd string), finish func(),
 	return exline
 }
 
-func (x *ExLine) TabComplete(tabComplete func(string) ([]string, string)) {
+func (x *ExLine) TabComplete(tabComplete func(context.Context, string) ([]opt.Completion, string)) {
 	x.input.TabComplete(
 		tabComplete,
 		config.Ui.CompletionDelay,
@@ -48,7 +51,7 @@ func (x *ExLine) TabComplete(tabComplete func(string) ([]string, string)) {
 }
 
 func NewPrompt(prompt string, commit func(text string),
-	tabcomplete func(cmd string) ([]string, string),
+	tabcomplete func(ctx context.Context, cmd string) ([]opt.Completion, string),
 ) *ExLine {
 	input := ui.NewTextInput("", config.Ui).Prompt(prompt)
 	if config.Ui.CompletionPopovers {
