@@ -31,7 +31,7 @@ type MessageList struct {
 
 func NewMessageList(account *AccountView) *MessageList {
 	ml := &MessageList{
-		spinner:       NewSpinner(account.uiConf),
+		spinner:       NewSpinner(account.UiConfig()),
 		isInitalizing: true,
 	}
 	// TODO: stop spinner, probably
@@ -44,7 +44,7 @@ func (ml *MessageList) Invalidate() {
 }
 
 type messageRowParams struct {
-	uid          uint32
+	uid          models.UID
 	needsHeaders bool
 	err          error
 	uiConfig     *config.UIConfig
@@ -61,7 +61,7 @@ func (ml *MessageList) AlignMessage(pos AlignPosition) {
 	idx := 0
 	iter := store.UidsIterator()
 	for i := 0; iter.Next(); i++ {
-		if store.SelectedUid() == iter.Value().(uint32) {
+		if store.SelectedUid() == iter.Value().(models.UID) {
 			idx = i
 			break
 		}
@@ -88,10 +88,11 @@ func (ml *MessageList) Draw(ctx *ui.Context) {
 		return
 	}
 
+	ml.SetOffset(uiConfig.MsglistScrollOffset)
 	ml.UpdateScroller(ml.height, len(store.Uids()))
 	iter := store.UidsIterator()
 	for i := 0; iter.Next(); i++ {
-		if store.SelectedUid() == iter.Value().(uint32) {
+		if store.SelectedUid() == iter.Value().(models.UID) {
 			ml.EnsureScroll(i)
 			break
 		}
@@ -107,7 +108,7 @@ func (ml *MessageList) Draw(ctx *ui.Context) {
 		return
 	}
 
-	var needsHeaders []uint32
+	var needsHeaders []models.UID
 
 	data := state.NewDataSetter()
 	data.SetAccount(acct.acct)
@@ -165,7 +166,7 @@ func (ml *MessageList) Draw(ctx *ui.Context) {
 		if i < ml.Scroll() {
 			continue
 		}
-		uid := iter.Value().(uint32)
+		uid := iter.Value().(models.UID)
 		if showThreads {
 			threadView.Update(data, uid)
 		}
@@ -200,7 +201,7 @@ func (ml *MessageList) Draw(ctx *ui.Context) {
 }
 
 func addMessage(
-	store *lib.MessageStore, uid uint32,
+	store *lib.MessageStore, uid models.UID,
 	table *ui.Table, data state.DataSetter,
 	uiConfig *config.UIConfig,
 ) bool {
@@ -225,6 +226,9 @@ func addMessage(
 	if msg.Flags.Has(models.AnsweredFlag) {
 		params.styles = append(params.styles, config.STYLE_MSGLIST_ANSWERED)
 	}
+	if msg.Flags.Has(models.ForwardedFlag) {
+		params.styles = append(params.styles, config.STYLE_MSGLIST_FORWARDED)
+	}
 	if msg.Flags.Has(models.FlaggedFlag) {
 		params.styles = append(params.styles, config.STYLE_MSGLIST_FLAGGED)
 	}
@@ -310,7 +314,11 @@ func (ml *MessageList) MouseEvent(localX int, localY int, event vaxis.Event) {
 							PushError(err.Error())
 							return
 						}
-						viewer := NewMessageViewer(acct, view)
+						viewer, err := NewMessageViewer(acct, view)
+						if err != nil {
+							PushError(err.Error())
+							return
+						}
 						NewTab(viewer, msg.Envelope.Subject)
 					})
 			}
@@ -354,8 +362,6 @@ func (ml *MessageList) storeUpdate(store *lib.MessageStore) {
 func (ml *MessageList) SetStore(store *lib.MessageStore) {
 	if ml.Store() != store {
 		ml.Scrollable = Scrollable{}
-		n := SelectedAccountUiConfig().MsglistScrollOffset
-		ml.SetOffset(n)
 	}
 	ml.store = store
 	if store != nil {
@@ -404,14 +410,14 @@ func (ml *MessageList) Select(index int) {
 
 	iter := store.UidsIterator()
 
-	var uid uint32
+	var uid models.UID
 	if index < 0 {
 		uid = uids[iter.EndIndex()]
 	} else {
 		uid = uids[iter.StartIndex()]
 		for i := 0; iter.Next(); i++ {
 			if i >= index {
-				uid = iter.Value().(uint32)
+				uid = iter.Value().(models.UID)
 				break
 			}
 		}
@@ -577,7 +583,7 @@ func newThreadView(store *lib.MessageStore) *threadView {
 	}
 }
 
-func (t *threadView) Update(data state.DataSetter, uid uint32) {
+func (t *threadView) Update(data state.DataSetter, uid models.UID) {
 	thread, err := t.store.Thread(uid)
 	info := state.ThreadInfo{}
 	if thread != nil && err == nil {
