@@ -8,6 +8,7 @@ import (
 	"io"
 	"os"
 	"os/exec"
+	"slices"
 	"strings"
 	"sync/atomic"
 
@@ -89,7 +90,7 @@ func NewMessageViewer(
 				hv.Name = header
 				showInfo = true
 			}
-			if parser := auth.New(header); parser != nil && msg.MessageInfo().Error == nil {
+			if parser := auth.New(header); parser != nil && msg.MessageInfo().RFC822Headers != nil {
 				details, err := parser(msg.MessageInfo().RFC822Headers, acct.AccountConfig().TrustedAuthRes)
 				if err != nil {
 					hv.Value = err.Error()
@@ -162,7 +163,7 @@ func fmtHeader(msg *models.MessageInfo, header string,
 	}
 
 	if v := auth.New(header); v != nil {
-		return "Fetching.."
+		return "Fetching..."
 	}
 
 	switch header {
@@ -231,6 +232,10 @@ func createSwitcher(
 		return fmt.Errorf("could not view message: %w", msg.MessageInfo().Error)
 	}
 
+	if msg.BodyStructure() == nil {
+		return fmt.Errorf("could not view message: no body")
+	}
+
 	if len(msg.BodyStructure().Parts) == 0 {
 		switcher.selected = 0
 		pv, err := NewPartViewer(acct, msg, msg.BodyStructure(), nil)
@@ -343,11 +348,6 @@ func (mv *MessageViewer) ToggleHeaders() {
 	switcher.Invalidate()
 }
 
-func (mv *MessageViewer) ToggleKeyPassthrough() bool {
-	config.Viewer.KeyPassthrough = !config.Viewer.KeyPassthrough
-	return config.Viewer.KeyPassthrough
-}
-
 func (mv *MessageViewer) SelectedMessagePart() *PartInfo {
 	if mv.switcher == nil {
 		return nil
@@ -544,6 +544,9 @@ func NewPartViewer(
 		if term, err = NewTerminal(pager); err != nil {
 			return nil, err
 		}
+		term.OnClose = func(error) {
+			SetKeyPassthrough(false)
+		}
 	} else {
 		noFilter = newNoFilterConfigured(acct.Name(), part)
 	}
@@ -707,7 +710,7 @@ func (pv *PartViewer) writeMailHeaders() {
 	// virtual header
 	if len(info.Labels) != 0 {
 		labels := fmtHeader(info, "Labels", "", "", "", "")
-		_, err := file.Write([]byte(fmt.Sprintf("\r\nLabels: %s", labels)))
+		_, err := fmt.Fprintf(file, "\r\nLabels: %s", labels)
 		if err != nil {
 			log.Errorf("failed to write to labels: %v", err)
 		}
@@ -722,7 +725,7 @@ func (pv *PartViewer) hyperlinks(r io.Reader) (reader io.Reader) {
 	if !config.Viewer.ParseHttpLinks {
 		return r
 	}
-	reader, pv.links = parse.HttpLinks(r)
+	reader, pv.links = parse.HttpLinks(r, pv.part.FullMIMEType() == "text/html")
 	return reader
 }
 
@@ -862,6 +865,15 @@ func (pv *PartViewer) resized(ctx *ui.Context) bool {
 
 func (pv *PartViewer) Event(event vaxis.Event) bool {
 	if pv.term != nil {
+		defer func() {
+			key, ok := event.(vaxis.Key)
+			if !ok {
+				return
+			}
+			if key.Matches(vaxis.KeyEnter, 0) {
+				SetKeyPassthrough(false)
+			}
+		}()
 		return pv.term.Event(event)
 	}
 	return false
@@ -905,10 +917,5 @@ func (hv *HeaderView) Invalidate() {
 }
 
 func canInline(mime string) bool {
-	for _, ext := range supportedImageTypes {
-		if mime == ext {
-			return true
-		}
-	}
-	return false
+	return slices.Contains(supportedImageTypes, mime)
 }
