@@ -13,8 +13,12 @@ func init() {
 	commands.Register(CheckMail{})
 }
 
+func (CheckMail) Description() string {
+	return "Check for new mail on the selected account."
+}
+
 func (CheckMail) Context() commands.CommandContext {
-	return commands.ACCOUNT
+	return commands.MESSAGE_LIST
 }
 
 func (CheckMail) Aliases() []string {
