@@ -9,13 +9,17 @@ import (
 )
 
 type Clear struct {
-	Selected bool `opt:"-s"`
+	Selected bool `opt:"-s" desc:"Select first message after clearing."`
 }
 
 func init() {
 	commands.Register(Clear{})
 }
 
+func (Clear) Description() string {
+	return "Clear the current search or filter criteria."
+}
+
 func (Clear) Context() commands.CommandContext {
 	return commands.MESSAGE_LIST
 }
@@ -35,7 +39,7 @@ func (c Clear) Execute(args []string) error {
 	}
 
 	if c.Selected {
-		defer store.Select(0)
+		defer store.Select("")
 	}
 	store.ApplyClear()
 	acct.SetStatus(state.SearchFilterClear())
