@@ -7,17 +7,21 @@ import (
 	"git.sr.ht/~rjarry/aerc/app"
 	"git.sr.ht/~rjarry/aerc/commands"
 	"git.sr.ht/~rjarry/aerc/worker/types"
-	"git.sr.ht/~rjarry/go-opt"
+	"git.sr.ht/~rjarry/go-opt/v2"
 )
 
 type MakeDir struct {
-	Folder string `opt:"folder" complete:"CompleteFolder"`
+	Folder string `opt:"folder" complete:"CompleteFolder" desc:"Folder name."`
 }
 
 func init() {
 	commands.Register(MakeDir{})
 }
 
+func (MakeDir) Description() string {
+	return "Create and change to a new folder."
+}
+
 func (MakeDir) Context() commands.CommandContext {
 	return commands.MESSAGE_LIST
 }
