@@ -13,16 +13,20 @@ import (
 type Sort struct {
 	Unused struct{} `opt:"-"`
 	// these fields are only used for completion
-	Reverse  bool     `opt:"-r"`
-	Criteria []string `opt:"criteria" complete:"CompleteCriteria"`
+	Reverse  bool     `opt:"-r" desc:"Sort in the reverse order."`
+	Criteria []string `opt:"criteria" complete:"CompleteCriteria" desc:"Sort criterion."`
 }
 
 func init() {
 	commands.Register(Sort{})
 }
 
+func (Sort) Description() string {
+	return "Sort the message list by the given criteria."
+}
+
 func (Sort) Context() commands.CommandContext {
-	return commands.ACCOUNT
+	return commands.MESSAGE_LIST
 }
 
 func (Sort) Aliases() []string {
