@@ -11,13 +11,17 @@ import (
 var previousDir string
 
 type ChangeDirectory struct {
-	Target string `opt:"directory" default:"~" complete:"CompleteTarget"`
+	Target string `opt:"directory" default:"~" complete:"CompleteTarget" desc:"Target directory."`
 }
 
 func init() {
 	Register(ChangeDirectory{})
 }
 
+func (ChangeDirectory) Description() string {
+	return "Change aerc's current working directory."
+}
+
 func (ChangeDirectory) Context() CommandContext {
 	return GLOBAL
 }
