@@ -9,13 +9,13 @@ import (
 	"strings"
 	"unicode"
 
-	"git.sr.ht/~rjarry/go-opt"
+	"git.sr.ht/~rjarry/go-opt/v2"
 
 	"git.sr.ht/~rjarry/aerc/app"
 	"git.sr.ht/~rjarry/aerc/config"
+	"git.sr.ht/~rjarry/aerc/lib/log"
 	"git.sr.ht/~rjarry/aerc/lib/state"
 	"git.sr.ht/~rjarry/aerc/lib/templates"
-	"git.sr.ht/~rjarry/aerc/log"
 	"git.sr.ht/~rjarry/aerc/models"
 )
 
@@ -26,13 +26,13 @@ const (
 	// available everywhere
 	GLOBAL
 	// only when a message list is focused
-	ACCOUNT
-	// only when a message composer is focused
-	COMPOSE
-	// only when a message list or message viewer is focused
-	MESSAGE
+	MESSAGE_LIST
 	// only when a message viewer is focused
 	MESSAGE_VIEWER
+	// only when a message composer editor is focused
+	COMPOSE_EDIT
+	// only when a message composer review screen is focused
+	COMPOSE_REVIEW
 	// only when a terminal
 	TERMINAL
 )
@@ -40,13 +40,17 @@ const (
 func CurrentContext() CommandContext {
 	var context CommandContext = GLOBAL
 
-	switch app.SelectedTabContent().(type) {
+	switch tab := app.SelectedTabContent().(type) {
 	case *app.AccountView:
-		context |= ACCOUNT | MESSAGE
+		context |= MESSAGE_LIST
 	case *app.Composer:
-		context |= COMPOSE
+		if tab.Bindings() == "compose::review" {
+			context |= COMPOSE_REVIEW
+		} else {
+			context |= COMPOSE_EDIT
+		}
 	case *app.MessageViewer:
-		context |= COMPOSE | MESSAGE | MESSAGE_VIEWER
+		context |= MESSAGE_VIEWER
 	case *app.Terminal:
 		context |= TERMINAL
 	}
@@ -55,6 +59,7 @@ func CurrentContext() CommandContext {
 }
 
 type Command interface {
+	Description() string
 	Context() CommandContext
 	Aliases() []string
 	Execute([]string) error
@@ -77,8 +82,14 @@ func Register(cmd Command) {
 func ActiveCommands() []Command {
 	var cmds []Command
 	context := CurrentContext()
+	seen := make(map[reflect.Type]bool)
 
 	for _, cmd := range allCommands {
+		t := reflect.TypeOf(cmd)
+		if seen[t] {
+			continue
+		}
+		seen[t] = true
 		if cmd.Context()&context != 0 {
 			cmds = append(cmds, cmd)
 		}
@@ -274,7 +285,7 @@ func GetTemplateCompletion(
 // GetCompletions returns the completion options and the command prefix
 func GetCompletions(
 	cmd Command, args *opt.Args,
-) (options []string, prefix string) {
+) (options []opt.Completion, prefix string) {
 	// copy zeroed struct
 	tmp := reflect.New(reflect.TypeOf(cmd)).Interface().(Command)
 	s, err := args.ArgSafe(0)
@@ -303,7 +314,7 @@ func GetTemplates(arg string) []string {
 			}
 		}
 	}
-	names := make([]string, len(templates))
+	names := make([]string, 0, len(templates))
 	for n := range templates {
 		names = append(names, n)
 	}
