@@ -6,15 +6,19 @@ import (
 )
 
 type CC struct {
-	Recipients string `opt:"recipients" complete:"CompleteAddress"`
+	Recipients string `opt:"recipients" complete:"CompleteAddress" desc:"Recipient from address book."`
 }
 
 func init() {
 	commands.Register(CC{})
 }
 
+func (CC) Description() string {
+	return "Add the given address(es) to the Cc or Bcc header."
+}
+
 func (CC) Context() commands.CommandContext {
-	return commands.COMPOSE
+	return commands.COMPOSE_EDIT | commands.COMPOSE_REVIEW
 }
 
 func (CC) Aliases() []string {
