@@ -9,9 +9,9 @@ import (
 )
 
 type Header struct {
-	Force  bool   `opt:"-f"`
-	Remove bool   `opt:"-d"`
-	Name   string `opt:"name" complete:"CompleteHeaders"`
+	Force  bool   `opt:"-f" desc:"Overwrite any existing header."`
+	Remove bool   `opt:"-d" desc:"Remove the header instead of adding it."`
+	Name   string `opt:"name" complete:"CompleteHeaders" desc:"Header name."`
 	Value  string `opt:"..." required:"false"`
 }
 
@@ -29,8 +29,12 @@ func init() {
 	commands.Register(Header{})
 }
 
+func (Header) Description() string {
+	return "Add or remove the specified email header."
+}
+
 func (Header) Context() commands.CommandContext {
-	return commands.COMPOSE
+	return commands.COMPOSE_EDIT | commands.COMPOSE_REVIEW
 }
 
 func (Header) Aliases() []string {
