@@ -13,8 +13,12 @@ func init() {
 	commands.Register(Sign{})
 }
 
+func (Sign) Description() string {
+	return "Sign the message using the account default key."
+}
+
 func (Sign) Context() commands.CommandContext {
-	return commands.COMPOSE
+	return commands.COMPOSE_EDIT | commands.COMPOSE_REVIEW
 }
 
 func (Sign) Aliases() []string {
