@@ -12,13 +12,17 @@ import (
 )
 
 type Eml struct {
-	Path string `opt:"path" required:"false" complete:"CompletePath"`
+	Path string `opt:"path" required:"false" complete:"CompletePath" desc:"EML file path."`
 }
 
 func init() {
 	Register(Eml{})
 }
 
+func (Eml) Description() string {
+	return "Open an eml file into the message viewer."
+}
+
 func (Eml) Context() CommandContext {
 	return GLOBAL
 }
@@ -49,7 +53,11 @@ func (e Eml) Execute(args []string) error {
 					app.PushError(err.Error())
 					return
 				}
-				msgView := app.NewMessageViewer(acct, view)
+				msgView, err := app.NewMessageViewer(acct, view)
+				if err != nil {
+					app.PushError(err.Error())
+					return
+				}
 				app.NewTab(msgView,
 					view.MessageInfo().Envelope.Subject)
 			})
