@@ -7,7 +7,7 @@ import (
 	"time"
 
 	"git.sr.ht/~rjarry/aerc/app"
-	"git.sr.ht/~rjarry/aerc/log"
+	"git.sr.ht/~rjarry/aerc/lib/log"
 )
 
 type ExecCmd struct {
@@ -18,6 +18,10 @@ func init() {
 	Register(ExecCmd{})
 }
 
+func (ExecCmd) Description() string {
+	return "Execute an arbitrary command in the background."
+}
+
 func (ExecCmd) Context() CommandContext {
 	return GLOBAL
 }
