@@ -9,31 +9,47 @@ import (
 	"git.sr.ht/~rjarry/aerc/commands"
 	"git.sr.ht/~rjarry/aerc/config"
 	"git.sr.ht/~rjarry/aerc/lib"
+	"git.sr.ht/~rjarry/aerc/lib/log"
 	"git.sr.ht/~rjarry/aerc/lib/marker"
 	"git.sr.ht/~rjarry/aerc/lib/ui"
-	"git.sr.ht/~rjarry/aerc/log"
 	"git.sr.ht/~rjarry/aerc/models"
 	"git.sr.ht/~rjarry/aerc/worker/types"
 )
 
 type Move struct {
-	CreateFolders bool   `opt:"-p"`
-	Account       string `opt:"-a" complete:"CompleteAccount"`
-	Folder        string `opt:"folder" complete:"CompleteFolder"`
+	CreateFolders     bool                     `opt:"-p" desc:"Create missing folders if required."`
+	Account           string                   `opt:"-a" complete:"CompleteAccount" desc:"Move to specified account."`
+	MultiFileStrategy *types.MultiFileStrategy `opt:"-m" action:"ParseMFS" complete:"CompleteMFS" desc:"Multi-file strategy."`
+	Folder            string                   `opt:"folder" complete:"CompleteFolder" desc:"Target folder."`
 }
 
 func init() {
 	commands.Register(Move{})
 }
 
+func (Move) Description() string {
+	return "Move the selected message(s) to the specified folder."
+}
+
 func (Move) Context() commands.CommandContext {
-	return commands.MESSAGE
+	return commands.MESSAGE_LIST | commands.MESSAGE_VIEWER
 }
 
 func (Move) Aliases() []string {
 	return []string{"mv", "move"}
 }
 
+func (m *Move) ParseMFS(arg string) error {
+	if arg != "" {
+		mfs, ok := types.StrToStrategy[arg]
+		if !ok {
+			return fmt.Errorf("invalid multi-file strategy %s", arg)
+		}
+		m.MultiFileStrategy = &mfs
+	}
+	return nil
+}
+
 func (*Move) CompleteAccount(arg string) []string {
 	return commands.FilterList(app.AccountNames(), arg, commands.QuoteSpace)
 }
@@ -51,6 +67,10 @@ func (m *Move) CompleteFolder(arg string) []string {
 	return commands.FilterList(acct.Directories().List(), arg, nil)
 }
 
+func (Move) CompleteMFS(arg string) []string {
+	return commands.FilterList(types.StrategyStrs(), arg, nil)
+}
+
 func (m Move) Execute(args []string) error {
 	h := newHelper()
 	acct, err := h.account()
@@ -71,9 +91,10 @@ func (m Move) Execute(args []string) error {
 	marker.ClearVisualMark()
 
 	if len(m.Account) == 0 {
-		store.Move(uids, m.Folder, m.CreateFolders, func(msg types.WorkerMessage) {
-			m.CallBack(msg, acct, uids, next, marker, false)
-		})
+		store.Move(uids, m.Folder, m.CreateFolders, m.MultiFileStrategy,
+			func(msg types.WorkerMessage) {
+				m.CallBack(msg, acct, uids, next, marker, false)
+			})
 		return nil
 	}
 
@@ -102,7 +123,7 @@ func (m Move) Execute(args []string) error {
 	// something is happening
 	app.PushStatus("Moving messages...", 10*time.Second)
 
-	var appended []uint32
+	var appended []models.UID
 	var timeout bool
 	go func() {
 		defer log.PanicHandler()
@@ -158,7 +179,8 @@ func (m Move) Execute(args []string) error {
 			}
 		}
 		if len(appended) > 0 {
-			store.Delete(appended, func(msg types.WorkerMessage) {
+			mfs := types.Refuse
+			store.Delete(appended, &mfs, func(msg types.WorkerMessage) {
 				m.CallBack(msg, acct, appended, next, marker, timeout)
 			})
 		}
@@ -169,19 +191,11 @@ func (m Move) Execute(args []string) error {
 func (m Move) CallBack(
 	msg types.WorkerMessage,
 	acct *app.AccountView,
-	uids []uint32,
+	uids []models.UID,
 	next *models.MessageInfo,
 	marker marker.Marker,
 	timeout bool,
 ) {
-	store := acct.Store()
-	sel := store.Selected()
-
-	dest := m.Folder
-	if len(m.Account) > 0 {
-		dest = fmt.Sprintf("%s in %s", m.Folder, m.Account)
-	}
-
 	switch msg := msg.(type) {
 	case *types.Done:
 		var s string
@@ -190,19 +204,24 @@ func (m Move) CallBack(
 		} else {
 			s = "%d message moved to %s"
 		}
+		dest := m.Folder
+		if len(m.Account) > 0 {
+			dest = fmt.Sprintf("%s in %s", m.Folder, m.Account)
+		}
 		if timeout {
 			s = "timed-out: only " + s
 			app.PushError(fmt.Sprintf(s, len(uids), dest))
 		} else {
 			app.PushStatus(fmt.Sprintf(s, len(uids), dest), 10*time.Second)
 		}
-		handleDone(acct, next, store)
+		if store := acct.Store(); store != nil {
+			handleDone(acct, next, store)
+		}
 	case *types.Error:
 		app.PushError(msg.Error.Error())
 		marker.Remark()
 	case *types.Unsupported:
 		marker.Remark()
-		store.Select(sel.Uid)
 		app.PushError("error, unsupported for this worker")
 	}
 }
@@ -231,7 +250,11 @@ func handleDone(
 					app.PushError(err.Error())
 					return
 				}
-				nextMv := app.NewMessageViewer(acct, view)
+				nextMv, err := app.NewMessageViewer(acct, view)
+				if err != nil {
+					app.PushError(err.Error())
+					return
+				}
 				app.ReplaceTab(mv, nextMv, next.Envelope.Subject, true)
 			})
 	default:
