@@ -2,7 +2,6 @@ package msg
 
 import (
 	"bytes"
-	"errors"
 	"fmt"
 	"io"
 	"os/exec"
@@ -11,6 +10,8 @@ import (
 	"strings"
 	"time"
 
+	"github.com/pkg/errors"
+
 	"git.sr.ht/~rjarry/aerc/app"
 	"git.sr.ht/~rjarry/aerc/commands"
 	cryptoutil "git.sr.ht/~rjarry/aerc/lib/crypto/util"
@@ -38,7 +39,7 @@ func (Pipe) Description() string {
 }
 
 func (Pipe) Context() commands.CommandContext {
-	return commands.MESSAGE_LIST | commands.MESSAGE_VIEWER
+	return commands.MESSAGE_LIST | commands.MESSAGE_VIEWER | commands.COMPOSE_REVIEW
 }
 
 func (Pipe) Aliases() []string {
@@ -49,6 +50,61 @@ func (p Pipe) Execute(args []string) error {
 	return p.Run(nil)
 }
 
+// doTerm executes the command in an interactive terminal tab
+func doTerm(command string, reader io.Reader, name string, silent bool, cb func()) {
+	cmd := []string{"sh", "-c", command}
+	term, err := commands.QuickTerm(cmd, reader, silent)
+	if err != nil {
+		app.PushError(err.Error())
+		return
+	}
+	if cb != nil {
+		last := term.OnClose
+		term.OnClose = func(err error) {
+			if last != nil {
+				last(err)
+			}
+			cb()
+		}
+	}
+	app.NewTab(term, name)
+}
+
+// doExec executes the command in the background
+func doExec(command string, reader io.Reader, name string, cb func()) {
+	ecmd := exec.Command("sh", "-c", command)
+	pipe, err := ecmd.StdinPipe()
+	if err != nil {
+		return
+	}
+	go func() {
+		defer log.PanicHandler()
+
+		defer pipe.Close()
+		_, err := io.Copy(pipe, reader)
+		if err != nil {
+			log.Errorf("failed to send data to pipe: %v", err)
+		}
+	}()
+	err = ecmd.Run()
+	if err != nil {
+		app.PushError(err.Error())
+	} else {
+		if ecmd.ProcessState.ExitCode() != 0 {
+			app.PushError(fmt.Sprintf(
+				"%s: completed with status %d", name,
+				ecmd.ProcessState.ExitCode()))
+		} else {
+			app.PushStatus(fmt.Sprintf(
+				"%s: completed with status %d", name,
+				ecmd.ProcessState.ExitCode()), 10*time.Second)
+		}
+	}
+	if cb != nil {
+		cb()
+	}
+}
+
 func (p Pipe) Run(cb func()) error {
 	if p.Decrypt {
 		// Decrypt implies fetching the full message
@@ -59,6 +115,32 @@ func (p Pipe) Run(cb func()) error {
 	}
 	name, _, _ := strings.Cut(p.Command, " ")
 
+	// Special handling for Composer in review mode
+	if composer, ok := app.SelectedTabContent().(*app.Composer); ok && composer.Bindings() == "compose::review" {
+		// Get the message content
+		header, err := composer.PrepareHeader()
+		if err != nil {
+			return errors.Wrap(err, "PrepareHeader")
+		}
+
+		pr, pw := io.Pipe()
+		go func() {
+			defer log.PanicHandler()
+			defer pw.Close()
+			err := composer.WriteMessage(header, pw)
+			if err != nil {
+				log.Errorf("failed to write message: %v", err)
+			}
+		}()
+
+		if p.Background {
+			doExec(p.Command, pr, name, cb)
+		} else {
+			doTerm(p.Command, pr, fmt.Sprintf("%s <review>", name), p.Silent, cb)
+		}
+		return nil
+	}
+
 	provider := app.SelectedTabContent().(app.ProvidesMessage)
 	if !p.Full && !p.Part {
 		if _, ok := provider.(*app.MessageViewer); ok {
@@ -71,59 +153,6 @@ func (p Pipe) Run(cb func()) error {
 		}
 	}
 
-	doTerm := func(reader io.Reader, name string) {
-		cmd := []string{"sh", "-c", p.Command}
-		term, err := commands.QuickTerm(cmd, reader, p.Silent)
-		if err != nil {
-			app.PushError(err.Error())
-			return
-		}
-		if cb != nil {
-			last := term.OnClose
-			term.OnClose = func(err error) {
-				if last != nil {
-					last(err)
-				}
-				cb()
-			}
-		}
-		app.NewTab(term, name)
-	}
-
-	doExec := func(reader io.Reader) {
-		ecmd := exec.Command("sh", "-c", p.Command)
-		pipe, err := ecmd.StdinPipe()
-		if err != nil {
-			return
-		}
-		go func() {
-			defer log.PanicHandler()
-
-			defer pipe.Close()
-			_, err := io.Copy(pipe, reader)
-			if err != nil {
-				log.Errorf("failed to send data to pipe: %v", err)
-			}
-		}()
-		err = ecmd.Run()
-		if err != nil {
-			app.PushError(err.Error())
-		} else {
-			if ecmd.ProcessState.ExitCode() != 0 {
-				app.PushError(fmt.Sprintf(
-					"%s: completed with status %d", name,
-					ecmd.ProcessState.ExitCode()))
-			} else {
-				app.PushStatus(fmt.Sprintf(
-					"%s: completed with status %d", name,
-					ecmd.ProcessState.ExitCode()), 10*time.Second)
-			}
-		}
-		if cb != nil {
-			cb()
-		}
-	}
-
 	app.PushStatus("Fetching messages ...", 10*time.Second)
 
 	if p.Full {
@@ -136,11 +165,11 @@ func (p Pipe) Run(cb func()) error {
 			if mv, ok := provider.(*app.MessageViewer); ok {
 				mv.MessageView().FetchFull(func(reader io.Reader) {
 					if p.Background {
-						doExec(reader)
+						doExec(p.Command, reader, name, cb)
 					} else {
-						doTerm(reader,
+						doTerm(p.Command, reader,
 							fmt.Sprintf("%s <%s",
-								name, title))
+								name, title), p.Silent, cb)
 					}
 				})
 				return nil
@@ -247,9 +276,9 @@ func (p Pipe) Run(cb func()) error {
 
 			reader := newMessagesReader(messages, len(messages) > 1)
 			if p.Background {
-				doExec(reader)
+				doExec(p.Command, reader, name, cb)
 			} else {
-				doTerm(reader, fmt.Sprintf("%s <%s", name, title))
+				doTerm(p.Command, reader, fmt.Sprintf("%s <%s", name, title), p.Silent, cb)
 			}
 		}()
 	} else if p.Part {
@@ -263,11 +292,11 @@ func (p Pipe) Run(cb func()) error {
 		}
 		mv.MessageView().FetchBodyPart(part.Index, func(reader io.Reader) {
 			if p.Background {
-				doExec(reader)
+				doExec(p.Command, reader, name, cb)
 			} else {
-				name := fmt.Sprintf("%s <%s/[%d]",
+				termName := fmt.Sprintf("%s <%s/[%d]",
 					name, part.Msg.Envelope.Subject, part.Index)
-				doTerm(reader, name)
+				doTerm(p.Command, reader, termName, p.Silent, cb)
 			}
 		})
 	}
