@@ -6,7 +6,7 @@ import (
 )
 
 type NextPrevPart struct {
-	Offset int `opt:"n" default:"1"`
+	Offset int `opt:"n" minus:"true" default:"1"`
 }
 
 func init() {
