@@ -5,7 +5,7 @@ import (
 )
 
 type NextPrevTab struct {
-	Offset int `opt:"n" default:"1"`
+	Offset int `opt:"n" minus:"true" default:"1"`
 }
 
 func init() {
