@@ -6,18 +6,22 @@ import (
 
 	"git.sr.ht/~rjarry/aerc/app"
 	"git.sr.ht/~rjarry/aerc/commands"
+	"git.sr.ht/~rjarry/aerc/lib/log"
 	"git.sr.ht/~rjarry/aerc/lib/pama"
-	"git.sr.ht/~rjarry/aerc/log"
 )
 
 type Drop struct {
-	Tag string `opt:"tag" complete:"CompleteTag"`
+	Tag string `opt:"tag" complete:"CompleteTag" desc:"Repository patch tag."`
 }
 
 func init() {
 	register(Drop{})
 }
 
+func (Drop) Description() string {
+	return "Drop a patch from the repository."
+}
+
 func (Drop) Context() commands.CommandContext {
 	return commands.GLOBAL
 }
