@@ -6,18 +6,22 @@ import (
 
 	"git.sr.ht/~rjarry/aerc/app"
 	"git.sr.ht/~rjarry/aerc/commands"
+	"git.sr.ht/~rjarry/aerc/lib/log"
 	"git.sr.ht/~rjarry/aerc/lib/pama"
-	"git.sr.ht/~rjarry/aerc/log"
 )
 
 type Switch struct {
-	Project string `opt:"project" complete:"Complete"`
+	Project string `opt:"project" complete:"Complete" desc:"Project name."`
 }
 
 func init() {
 	register(Switch{})
 }
 
+func (Switch) Description() string {
+	return "Switch context to the specified project."
+}
+
 func (Switch) Context() commands.CommandContext {
 	return commands.GLOBAL
 }
