@@ -7,19 +7,23 @@ import (
 )
 
 type Quit struct {
-	Force bool `opt:"-f"`
+	Force bool `opt:"-f" desc:"Force quit even if a task is pending."`
 }
 
 func init() {
 	Register(Quit{})
 }
 
+func (Quit) Description() string {
+	return "Exit aerc."
+}
+
 func (Quit) Context() CommandContext {
 	return GLOBAL
 }
 
 func (Quit) Aliases() []string {
-	return []string{"quit", "exit"}
+	return []string{"quit", "q", "exit"}
 }
 
 type ErrorExit int
