@@ -10,7 +10,7 @@ import (
 )
 
 type Zoxide struct {
-	Args []string `opt:"..." required:"false" metavar:"<query>..." complete:"CompleteFolder"`
+	Args []string `opt:"..." required:"false" metavar:"<query>..." complete:"CompleteFolder" desc:"Target folder."`
 }
 
 func ZoxideAdd(arg string) error {
@@ -34,6 +34,10 @@ func init() {
 	}
 }
 
+func (Zoxide) Description() string {
+	return "Change aerc's current working directory using zoxide."
+}
+
 func (Zoxide) Context() CommandContext {
 	return GLOBAL
 }
