@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"os"
 	"path"
+	"slices"
 	"strings"
 
 	"git.sr.ht/~rjarry/aerc/lib/xdg"
@@ -33,6 +34,10 @@ func buildDefaultDirs() []string {
 		}
 	}
 
+	// Trim null chars inserted post-build by systems like Conda
+	shareDir := strings.TrimRight(shareDir, "\x00")
+	libexecDir := strings.TrimRight(libexecDir, "\x00")
+
 	// Add custom buildtime dirs
 	if libexecDir != "" && libexecDir != "/usr/local/libexec/aerc" {
 		defaultDirs = append(defaultDirs, xdg.ExpandHome(libexecDir))
@@ -134,6 +139,7 @@ func LoadConfigFromFile(
 			}
 		}
 	}
+	SetConfFilename(filename)
 	if err := parseConf(filename); err != nil {
 		return fmt.Errorf("%s: %w", filename, err)
 	}
@@ -156,12 +162,7 @@ func parseLayout(layout string) [][]string {
 }
 
 func contains(list []string, v string) bool {
-	for _, item := range list {
-		if item == v {
-			return true
-		}
-	}
-	return false
+	return slices.Contains(list, v)
 }
 
 // warning message related to configuration (deprecation, etc.)
