@@ -8,13 +8,10 @@ import (
 	"git.sr.ht/~rjarry/aerc/models"
 )
 
-// Encrypt runs gpg --encrypt [--sign] -r [recipient]. The default is to have
-// --trust-model always set
+// Encrypt runs gpg --encrypt [--sign] -r [recipient]
 func Encrypt(r io.Reader, to []string, from string) ([]byte, error) {
-	//TODO probably shouldn't have --trust-model always a default
 	args := []string{
 		"--armor",
-		"--trust-model", "always",
 	}
 	if from != "" {
 		args = append(args, "--sign", "--default-key", from)
@@ -25,15 +22,12 @@ func Encrypt(r io.Reader, to []string, from string) ([]byte, error) {
 	args = append(args, "--encrypt", "-")
 
 	g := newGpg(r, args)
-	g.cmd.Run()
-	outRdr := bytes.NewReader(g.stdout.Bytes())
+	_ = g.cmd.Run()
 	var md models.MessageDetails
-	err := parse(outRdr, &md)
+	err := parseStatusFd(bytes.NewReader(g.stderr.Bytes()), &md)
 	if err != nil {
-		return nil, fmt.Errorf("gpg: failure to encrypt: %v. check public key(s)", err)
+		return nil, fmt.Errorf("gpg: failure to encrypt: %w. check public key(s)", err)
 	}
-	var buf bytes.Buffer
-	io.Copy(&buf, md.Body)
 
-	return buf.Bytes(), nil
+	return g.stdout.Bytes(), nil
 }
