@@ -12,6 +12,7 @@ import (
 	"strings"
 
 	"git.sr.ht/~rjarry/aerc/lib/crypto/gpg/gpgbin"
+	"git.sr.ht/~rjarry/aerc/lib/pinentry"
 	"git.sr.ht/~rjarry/aerc/models"
 	"github.com/emersion/go-message/textproto"
 )
@@ -92,6 +93,9 @@ func newEncryptedReader(h textproto.Header, mr *textproto.MultipartReader) (*Rea
 		return nil, fmt.Errorf("gpgmail: second part in multipart/encrypted message has type %q, not application/octet-stream", t)
 	}
 
+	pinentry.Enable()
+	defer pinentry.Disable()
+
 	md, err := gpgbin.Decrypt(p)
 	if err != nil {
 		return nil, fmt.Errorf("gpgmail: failed to read PGP message: %w", err)
