@@ -8,7 +8,9 @@ import (
 
 type MailDeleted struct {
 	Account string
+	Backend string
 	Folder  string
+	Role    string
 }
 
 func (m *MailDeleted) Cmd() string {
@@ -18,6 +20,8 @@ func (m *MailDeleted) Cmd() string {
 func (m *MailDeleted) Env() []string {
 	return []string{
 		fmt.Sprintf("AERC_ACCOUNT=%s", m.Account),
+		fmt.Sprintf("AERC_ACCOUNT_BACKEND=%s", m.Backend),
 		fmt.Sprintf("AERC_FOLDER=%s", m.Folder),
+		fmt.Sprintf("AERC_FOLDER_ROLE=%s", m.Role),
 	}
 }
