@@ -1,13 +1,21 @@
 package marker
 
+import (
+	"maps"
+	"slices"
+	"sync"
+
+	"git.sr.ht/~rjarry/aerc/models"
+)
+
 // Marker provides the interface for the marking behavior of messages
 type Marker interface {
-	Mark(uint32)
-	Unmark(uint32)
-	ToggleMark(uint32)
+	Mark(models.UID)
+	Unmark(models.UID)
+	ToggleMark(models.UID)
 	Remark()
-	Marked() []uint32
-	IsMarked(uint32) bool
+	Marked() []models.UID
+	IsMarked(models.UID) bool
 	IsVisualMark() bool
 	ToggleVisualMark(bool)
 	UpdateVisualMark()
@@ -16,54 +24,62 @@ type Marker interface {
 
 // UIDProvider provides the underlying uids and the selected message index
 type UIDProvider interface {
-	Uids() []uint32
+	Uids() []models.UID
 	SelectedIndex() int
 }
 
 type controller struct {
 	uidProvider    UIDProvider
-	marked         map[uint32]struct{}
-	lastMarked     map[uint32]struct{}
-	visualStartUID uint32
+	markedMtx      sync.RWMutex
+	marked         map[models.UID]struct{}
+	lastMarked     map[models.UID]struct{}
+	visualStartUID models.UID
 	visualMarkMode bool
-	visualBase     map[uint32]struct{}
+	visualBaseMtx  sync.RWMutex
+	visualBase     map[models.UID]struct{}
 }
 
 // New returns a new Marker
 func New(up UIDProvider) Marker {
 	return &controller{
 		uidProvider: up,
-		marked:      make(map[uint32]struct{}),
-		lastMarked:  make(map[uint32]struct{}),
+		marked:      make(map[models.UID]struct{}),
+		lastMarked:  make(map[models.UID]struct{}),
 	}
 }
 
-// Mark markes the uid as marked
-func (mc *controller) Mark(uid uint32) {
+// Mark marks the uid as marked
+func (mc *controller) Mark(uid models.UID) {
 	if mc.visualMarkMode {
 		// visual mode has override, bogus input from user
 		return
 	}
+	mc.markedMtx.Lock()
 	mc.marked[uid] = struct{}{}
+	mc.markedMtx.Unlock()
 }
 
 // Unmark unmarks the uid
-func (mc *controller) Unmark(uid uint32) {
+func (mc *controller) Unmark(uid models.UID) {
 	if mc.visualMarkMode {
 		// user probably wanted to clear the visual marking
 		mc.ClearVisualMark()
 		return
 	}
+	mc.markedMtx.Lock()
 	delete(mc.marked, uid)
+	mc.markedMtx.Unlock()
 }
 
 // Remark restores the previous marks
 func (mc *controller) Remark() {
+	mc.markedMtx.Lock()
 	mc.marked = mc.lastMarked
+	mc.markedMtx.Unlock()
 }
 
 // ToggleMark toggles the marked state for the given uid
-func (mc *controller) ToggleMark(uid uint32) {
+func (mc *controller) ToggleMark(uid models.UID) {
 	if mc.visualMarkMode {
 		// visual mode has override, bogus input from user
 		return
@@ -77,20 +93,18 @@ func (mc *controller) ToggleMark(uid uint32) {
 
 // resetMark removes the marking from all messages
 func (mc *controller) resetMark() {
+	mc.markedMtx.Lock()
 	mc.lastMarked = mc.marked
-	mc.marked = make(map[uint32]struct{})
+	mc.marked = make(map[models.UID]struct{})
+	mc.markedMtx.Unlock()
 }
 
 // removeStaleUID removes uids that are no longer presents in the UIDProvider
 func (mc *controller) removeStaleUID() {
+	mc.markedMtx.Lock()
+	defer mc.markedMtx.Unlock()
 	for mark := range mc.marked {
-		present := false
-		for _, uid := range mc.uidProvider.Uids() {
-			if mark == uid {
-				present = true
-				break
-			}
-		}
+		present := slices.Contains(mc.uidProvider.Uids(), mark)
 		if !present {
 			delete(mc.marked, mark)
 		}
@@ -98,16 +112,20 @@ func (mc *controller) removeStaleUID() {
 }
 
 // IsMarked checks whether the given uid has been marked
-func (mc *controller) IsMarked(uid uint32) bool {
+func (mc *controller) IsMarked(uid models.UID) bool {
+	mc.markedMtx.RLock()
 	_, marked := mc.marked[uid]
+	mc.markedMtx.RUnlock()
 	return marked
 }
 
 // Marked returns the uids of all marked messages
-func (mc *controller) Marked() []uint32 {
+func (mc *controller) Marked() []models.UID {
 	mc.removeStaleUID()
-	marked := make([]uint32, len(mc.marked))
+	marked := make([]models.UID, len(mc.marked))
 	i := 0
+	mc.markedMtx.RLock()
+	defer mc.markedMtx.RUnlock()
 	for uid := range mc.marked {
 		marked[i] = uid
 		i++
@@ -131,11 +149,15 @@ func (mc *controller) ToggleVisualMark(clear bool) {
 		uids := mc.uidProvider.Uids()
 		if idx := mc.uidProvider.SelectedIndex(); idx >= 0 && idx < len(uids) {
 			mc.visualStartUID = uids[idx]
+			mc.markedMtx.Lock()
 			mc.marked[mc.visualStartUID] = struct{}{}
-			mc.visualBase = make(map[uint32]struct{})
-			for key, value := range mc.marked {
-				mc.visualBase[key] = value
-			}
+			mc.markedMtx.Unlock()
+			mc.visualBase = make(map[models.UID]struct{})
+			mc.markedMtx.RLock()
+			defer mc.markedMtx.RUnlock()
+			mc.visualBaseMtx.Lock()
+			defer mc.visualBaseMtx.Unlock()
+			maps.Copy(mc.visualBase, mc.marked)
 		}
 	}
 }
@@ -144,7 +166,7 @@ func (mc *controller) ToggleVisualMark(clear bool) {
 func (mc *controller) ClearVisualMark() {
 	mc.resetMark()
 	mc.visualMarkMode = false
-	mc.visualStartUID = 0
+	mc.visualStartUID = ""
 }
 
 // UpdateVisualMark updates the index with the currently selected message
@@ -167,13 +189,15 @@ func (mc *controller) UpdateVisualMark() {
 
 	uids := mc.uidProvider.Uids()
 
-	var visUids []uint32
+	var visUids []models.UID
 	if selectedIdx > startIdx {
 		visUids = uids[startIdx : selectedIdx+1]
 	} else {
 		visUids = uids[selectedIdx : startIdx+1]
 	}
-	mc.marked = make(map[uint32]struct{})
+	mc.markedMtx.Lock()
+	defer mc.markedMtx.Unlock()
+	mc.marked = make(map[models.UID]struct{})
 	for uid := range mc.visualBase {
 		mc.marked[uid] = struct{}{}
 	}
