@@ -3,6 +3,7 @@ package lib
 import (
 	"context"
 	"fmt"
+
 	"github.com/emersion/go-imap/client"
 	"github.com/emersion/go-sasl"
 	"golang.org/x/oauth2"
@@ -22,7 +23,7 @@ func (c *OAuthBearer) ExchangeRefreshToken(refreshToken string) (*oauth2.Token,
 
 func (c *OAuthBearer) Authenticate(username string, password string, client *client.Client) error {
 	if ok, err := client.SupportAuth(sasl.OAuthBearer); err != nil || !ok {
-		return fmt.Errorf("OAuthBearer not supported %v", err)
+		return fmt.Errorf("OAuthBearer not supported %w", err)
 	}
 
 	if c.OAuth2.Endpoint.TokenURL != "" {
