@@ -38,8 +38,8 @@ func TestMessageInfoParser(t *testing.T) {
 	}
 }
 
-func TestMessageInfoHandledError(t *testing.T) {
-	rootDir := "testdata/message/invalid"
+func TestMessageInfoMalformed(t *testing.T) {
+	rootDir := "testdata/message/malformed"
 	msgFiles, err := os.ReadDir(rootDir)
 	die(err)
 
@@ -51,14 +51,10 @@ func TestMessageInfoHandledError(t *testing.T) {
 		p := fi.Name()
 		t.Run(p, func(t *testing.T) {
 			m := newMockRawMessageFromPath(filepath.Join(rootDir, p))
-			mi, err := MessageInfo(m)
+			_, err := MessageInfo(m)
 			if err != nil {
 				t.Fatal(err)
 			}
-
-			if perr := mi.Error; perr == nil {
-				t.Fatal("Expected MessageInfo.Error, got none")
-			}
 		})
 	}
 }
@@ -185,7 +181,7 @@ func (m *mockRawMessage) NewReader() (io.ReadCloser, error) {
 }
 func (m *mockRawMessage) ModelFlags() (models.Flags, error) { return 0, nil }
 func (m *mockRawMessage) Labels() ([]string, error)         { return nil, nil }
-func (m *mockRawMessage) UID() uint32                       { return 0 }
+func (m *mockRawMessage) UID() models.UID                   { return "" }
 
 func die(err error) {
 	if err != nil {
