@@ -4,7 +4,7 @@
 package watchers
 
 import (
-	"git.sr.ht/~rjarry/aerc/log"
+	"git.sr.ht/~rjarry/aerc/lib/log"
 	"github.com/fsnotify/fsnotify"
 )
 
