@@ -3,6 +3,7 @@ package imap
 import (
 	"bufio"
 	"fmt"
+	"time"
 
 	"github.com/emersion/go-imap"
 	"github.com/emersion/go-message"
@@ -14,8 +15,26 @@ import (
 	"git.sr.ht/~rjarry/aerc/lib/parse"
 	"git.sr.ht/~rjarry/aerc/models"
 	"git.sr.ht/~rjarry/aerc/worker/types"
+	"github.com/emersion/go-imap/utf7"
 )
 
+func (imapw *IMAPWorker) attachGMLabels(_msg *imap.Message, info *models.MessageInfo) {
+	if len(_msg.Items["X-GM-LABELS"].([]interface{})) == 0 {
+		return
+	}
+	imapw.worker.Debugf("Attaching labels %v to message %v\n", _msg.Items["X-GM-LABELS"], _msg.Uid)
+	enc := utf7.Encoding.NewDecoder()
+	for _, label := range _msg.Items["X-GM-LABELS"].([]any) {
+		decodedLabel, err := enc.String(label.(string))
+		if err != nil {
+			imapw.worker.Errorf("Failed to decode label %v from UTF-7\n", label.(string))
+			info.Labels = append(info.Labels, label.(string))
+		} else {
+			info.Labels = append(info.Labels, decodedLabel)
+		}
+	}
+}
+
 func (imapw *IMAPWorker) handleFetchMessageHeaders(
 	msg *types.FetchMessageHeaders,
 ) {
@@ -26,7 +45,8 @@ func (imapw *IMAPWorker) handleFetchMessageHeaders(
 		return
 	}
 	toFetch := msg.Uids
-	if imapw.config.cacheEnabled && imapw.cache != nil {
+	cacheEnabled := imapw.config.cacheEnabled && imapw.cache != nil
+	if cacheEnabled {
 		toFetch = imapw.getCachedHeaders(msg)
 	}
 	if len(toFetch) == 0 {
@@ -59,6 +79,7 @@ func (imapw *IMAPWorker) handleFetchMessageHeaders(
 		imap.FetchRFC822Size,
 		section.FetchItem(),
 	}
+
 	imapw.handleFetchMessages(msg, toFetch, items,
 		func(_msg *imap.Message) error {
 			if len(_msg.Body) == 0 {
@@ -84,6 +105,18 @@ func (imapw *IMAPWorker) handleFetchMessageHeaders(
 				Size:          _msg.Size,
 				Uid:           models.Uint32ToUid(_msg.Uid),
 			}
+
+			if imapw.caps.Has("X-GM-EXT-1") {
+				imapw.attachGMLabels(_msg, info)
+			}
+
+			if cacheEnabled && !info.Flags.Has(models.SeenFlag) &&
+				time.Since(info.InternalDate) < imapw.config.checkMail {
+				// Consider unread messages received within the last CheckMail
+				// period as Recent, regardless of what the IMAP server says.
+				info.Flags |= models.RecentFlag
+			}
+
 			imapw.worker.PostMessage(&types.MessageInfo{
 				Message: types.RespondTo(msg),
 				Info:    info,
@@ -158,12 +191,16 @@ func (imapw *IMAPWorker) handleFetchMessageBodyPart(
 				},
 			}, nil)
 			// Update flags (to mark message as read)
+			info := &models.MessageInfo{
+				Flags: translateImapFlags(_msg.Flags),
+				Uid:   models.Uint32ToUid(_msg.Uid),
+			}
+			if imapw.caps.Has("X-GM-EXT-1") {
+				imapw.attachGMLabels(_msg, info)
+			}
 			imapw.worker.PostMessage(&types.MessageInfo{
 				Message: types.RespondTo(msg),
-				Info: &models.MessageInfo{
-					Flags: translateImapFlags(_msg.Flags),
-					Uid:   models.Uint32ToUid(_msg.Uid),
-				},
+				Info:    info,
 			}, nil)
 			return nil
 		})
@@ -200,12 +237,16 @@ func (imapw *IMAPWorker) handleFetchFullMessages(
 				},
 			}, nil)
 			// Update flags (to mark message as read)
+			info := &models.MessageInfo{
+				Flags: translateImapFlags(_msg.Flags),
+				Uid:   models.Uint32ToUid(_msg.Uid),
+			}
+			if imapw.caps.Has("X-GM-EXT-1") {
+				imapw.attachGMLabels(_msg, info)
+			}
 			imapw.worker.PostMessage(&types.MessageInfo{
 				Message: types.RespondTo(msg),
-				Info: &models.MessageInfo{
-					Flags: translateImapFlags(_msg.Flags),
-					Uid:   models.Uint32ToUid(_msg.Uid),
-				},
+				Info:    info,
 			}, nil)
 			return nil
 		})
@@ -216,6 +257,7 @@ func (imapw *IMAPWorker) handleFetchMessageFlags(msg *types.FetchMessageFlags) {
 		imap.FetchFlags,
 		imap.FetchUid,
 	}
+
 	if msg.Context.Err() != nil {
 		imapw.worker.PostMessage(&types.Cancelled{
 			Message: types.RespondTo(msg),
@@ -224,12 +266,18 @@ func (imapw *IMAPWorker) handleFetchMessageFlags(msg *types.FetchMessageFlags) {
 	}
 	imapw.handleFetchMessages(msg, msg.Uids, items,
 		func(_msg *imap.Message) error {
+			info := &models.MessageInfo{
+				Flags: translateImapFlags(_msg.Flags),
+				Uid:   models.Uint32ToUid(_msg.Uid),
+			}
+
+			if imapw.caps.Has("X-GM-EXT-1") {
+				imapw.attachGMLabels(_msg, info)
+			}
+
 			imapw.worker.PostMessage(&types.MessageInfo{
 				Message: types.RespondTo(msg),
-				Info: &models.MessageInfo{
-					Flags: translateImapFlags(_msg.Flags),
-					Uid:   models.Uint32ToUid(_msg.Uid),
-				},
+				Info:    info,
 			}, nil)
 			return nil
 		})
@@ -254,7 +302,7 @@ func (imapw *IMAPWorker) handleFetchMessages(
 			delete(missingUids, models.Uint32ToUid(_msg.Uid))
 			err := procFunc(_msg)
 			if err != nil {
-				log.Errorf("failed to process message <%d>: %v", _msg.Uid, err)
+				imapw.worker.Errorf("failed to process message <%d>: %v", _msg.Uid, err)
 				imapw.worker.PostMessage(&types.MessageInfo{
 					Message: types.RespondTo(msg),
 					Info: &models.MessageInfo{
@@ -267,6 +315,10 @@ func (imapw *IMAPWorker) handleFetchMessages(
 		close(done)
 	}()
 
+	if imapw.caps.Has("X-GM-EXT-1") {
+		items = append(items, "X-GM-LABELS")
+	}
+
 	set := toSeqSet(uids)
 	if err := imapw.client.UidFetch(set, items, messages); err != nil {
 		imapw.worker.PostMessage(&types.Error{
