@@ -14,12 +14,12 @@ func init() {
 	imap.CharsetReader = charset.Reader
 }
 
-func toSeqSet(uids []uint32) *imap.SeqSet {
-	var set imap.SeqSet
+func toSeqSet(uids []models.UID) *imap.SeqSet {
+	set := new(imap.SeqSet)
 	for _, uid := range uids {
-		set.AddNum(uid)
+		set.AddNum(models.UidToUint32(uid))
 	}
-	return &set
+	return set
 }
 
 func translateBodyStructure(bs *imap.BodyStructure) *models.BodyStructure {
@@ -50,11 +50,6 @@ func translateEnvelope(e *imap.Envelope) *models.Envelope {
 		return nil
 	}
 
-	// we strip the msgid of "<>" in order to be more compatible with go-message
-	// which wants to handle msgids without the markers
-	msgID := strings.TrimSuffix(strings.TrimPrefix(e.MessageId, "<"), ">")
-	inReplyTo := strings.TrimSuffix(strings.TrimPrefix(e.InReplyTo, "<"), ">")
-
 	return &models.Envelope{
 		Date:      e.Date,
 		Subject:   e.Subject,
@@ -63,11 +58,17 @@ func translateEnvelope(e *imap.Envelope) *models.Envelope {
 		To:        translateAddresses(e.To),
 		Cc:        translateAddresses(e.Cc),
 		Bcc:       translateAddresses(e.Bcc),
-		MessageId: msgID,
-		InReplyTo: inReplyTo,
+		MessageId: translateMessageID(e.MessageId),
+		InReplyTo: translateMessageID(e.InReplyTo),
 	}
 }
 
+func translateMessageID(messageID string) string {
+	// Strip away unwanted characters, go-message expects the message id
+	// without brackets, spaces, tabs and new lines.
+	return strings.Trim(messageID, "<> \t\r\n")
+}
+
 func translateAddresses(addrs []*imap.Address) []*mail.Address {
 	var converted []*mail.Address
 	for _, addr := range addrs {
