@@ -13,11 +13,15 @@ import (
 func (imapw *IMAPWorker) handleListDirectories(msg *types.ListDirectories) {
 	mailboxes := make(chan *imap.MailboxInfo)
 	imapw.worker.Tracef("Listing mailboxes")
-	done := make(chan interface{})
+	done := make(chan any)
 
 	go func() {
 		defer log.PanicHandler()
 
+		labels := make([]string, 0)
+		provider := imapw.config.provider
+		useLabels := provider == GMail || provider == Proton
+
 		for mbox := range mailboxes {
 			if !canOpen(mbox) {
 				// no need to pass this to handlers if it can't be opened
@@ -26,6 +30,16 @@ func (imapw *IMAPWorker) handleListDirectories(msg *types.ListDirectories) {
 			dir := &models.Directory{
 				Name: mbox.Name,
 			}
+			switch provider {
+			case GMail:
+				labels = append(labels, mbox.Name)
+			case Proton:
+				if strings.HasPrefix(mbox.Name, "Labels/") {
+					labels = append(labels, strings.TrimPrefix(mbox.Name, "Labels/"))
+				}
+			default:
+				// No label support
+			}
 			for _, attr := range mbox.Attributes {
 				attr = strings.TrimPrefix(attr, "\\")
 				attr = strings.ToLower(attr)
@@ -43,6 +57,12 @@ func (imapw *IMAPWorker) handleListDirectories(msg *types.ListDirectories) {
 				Dir:     dir,
 			}, nil)
 		}
+
+		if useLabels {
+			imapw.worker.Debugf("Available labels: %s", labels)
+			imapw.worker.PostMessage(&types.LabelList{Labels: labels}, nil)
+		}
+
 		done <- nil
 	}()
 
