@@ -3,6 +3,7 @@ package imap
 import (
 	"io"
 
+	"git.sr.ht/~rjarry/aerc/models"
 	"git.sr.ht/~rjarry/aerc/worker/types"
 )
 
@@ -51,6 +52,9 @@ func (imapw *IMAPWorker) handleMoveMessages(msg *types.MoveMessages) {
 	drain := imapw.drainUpdates()
 	defer drain.Close()
 
+	// Build provider-dependent EXPUNGE handler.
+	imapw.BuildExpungeHandler(models.UidToUint32List(msg.Uids), false)
+
 	uids := toSeqSet(msg.Uids)
 	if err := imapw.client.UidMove(uids, msg.Destination); err != nil {
 		imapw.worker.PostMessage(&types.Error{
