@@ -31,6 +31,18 @@ var (
 	errAlreadyConnected = fmt.Errorf("already connected")
 )
 
+type imapProvider uint32
+
+const (
+	Unknown imapProvider = iota
+	GMail
+	Proton
+	Office365
+	Zoho
+	FastMail
+	iCloud
+)
+
 type imapClient struct {
 	*client.Client
 	thread     *sortthread.ThreadClient
@@ -43,6 +55,7 @@ type imapConfig struct {
 	scheme            string
 	insecure          bool
 	addr              string
+	provider          imapProvider
 	user              *url.Userinfo
 	headers           []string
 	headersExclude    []string
@@ -59,7 +72,8 @@ type imapConfig struct {
 	keepalive_interval int
 	cacheEnabled       bool
 	cacheMaxAge        time.Duration
-	useXGMEXT          bool
+	expungePolicy      int
+	checkMail          time.Duration
 }
 
 type IMAPWorker struct {
@@ -70,6 +84,7 @@ type IMAPWorker struct {
 	updates   chan client.Update
 	worker    types.WorkerInteractor
 	seqMap    SeqMap
+	expunger  *ExpungeHandler
 	delimiter string
 
 	idler    *idler
@@ -81,18 +96,21 @@ type IMAPWorker struct {
 	threadAlgorithm sortthread.ThreadAlgorithm
 	liststatus      bool
 
+	noCheckMailBefore time.Time
+
 	executeIdle chan struct{}
 }
 
 func NewIMAPWorker(worker *types.Worker) (types.Backend, error) {
 	return &IMAPWorker{
-		updates:     make(chan client.Update, 50),
-		worker:      worker,
-		selected:    &imap.MailboxStatus{},
-		idler:       nil, // will be set in configure()
-		observer:    nil, // will be set in configure()
-		caps:        &models.Capabilities{},
-		executeIdle: make(chan struct{}),
+		updates:           make(chan client.Update, 50),
+		worker:            worker,
+		selected:          &imap.MailboxStatus{},
+		idler:             nil, // will be set in configure()
+		observer:          nil, // will be set in configure()
+		caps:              &models.Capabilities{},
+		noCheckMailBefore: time.Now(),
+		executeIdle:       make(chan struct{}),
 	}, nil
 }
 
@@ -132,14 +150,15 @@ func (w *IMAPWorker) newClient(c *client.Client) {
 		w.worker.Debugf("Server Capability found: LIST-STATUS")
 	}
 	xgmext, err := w.client.Support("X-GM-EXT-1")
-	if err == nil && xgmext && w.config.useXGMEXT {
+	if err == nil && xgmext {
 		w.caps.Extensions = append(w.caps.Extensions, "X-GM-EXT-1")
 		w.worker.Debugf("Server Capability found: X-GM-EXT-1")
+		if w.config.provider != GMail {
+			w.worker.Warnf("Provider detection issue; setting to GMail since X-GM-EXT-1 is supported")
+			w.config.provider = GMail
+		}
 		w.worker = middleware.NewGmailWorker(w.worker, w.client.Client)
 	}
-	if err == nil && !xgmext && w.config.useXGMEXT {
-		w.worker.Infof("X-GM-EXT-1 requested, but it is not supported")
-	}
 }
 
 func (w *IMAPWorker) handleMessage(msg types.WorkerMessage) error {
@@ -201,19 +220,29 @@ func (w *IMAPWorker) handleMessage(msg types.WorkerMessage) error {
 
 		w.worker.PostMessage(&types.Done{Message: types.RespondTo(msg)}, nil)
 	case *types.Disconnect:
+		// Reset the observer.
 		w.observer.SetAutoReconnect(false)
 		w.observer.Stop()
+		w.observer.SetClient(nil)
 
-		if w.client == nil || (w.client != nil && w.client.State() != imap.SelectedState) {
-			reterr = errNotConnected
-			break
+		// Reset the idler, if any.
+		if w.idler != nil {
+			w.idler.SetClient(nil)
 		}
 
+		// Logout and reset the client.
+		if w.client == nil || (w.client != nil && w.client.State() != imap.SelectedState) {
+			reterr = errNotConnected
+			w.client = nil
+			break
+		}
 		if err := w.client.Logout(); err != nil {
 			w.terminate()
 			reterr = err
 			break
 		}
+		w.client = nil
+
 		w.worker.PostMessage(&types.Done{Message: types.RespondTo(msg)}, nil)
 	case *types.ListDirectories:
 		w.handleListDirectories(msg)
@@ -251,6 +280,8 @@ func (w *IMAPWorker) handleMessage(msg types.WorkerMessage) error {
 		w.handleSearchDirectory(msg)
 	case *types.CheckMail:
 		w.handleCheckMailMessage(msg)
+	case *types.ModifyLabels:
+		w.handleModifyLabels(msg)
 	default:
 		reterr = errUnsupported
 	}
@@ -267,9 +298,21 @@ func (w *IMAPWorker) handleImapUpdate(update client.Update) {
 	w.worker.Tracef("(= %T", update)
 	switch update := update.(type) {
 	case *client.MailboxUpdate:
-		w.worker.PostAction(&types.CheckMail{
-			Directories: []string{update.Mailbox.Name},
-		}, nil)
+		now := time.Now()
+		// Since go-imap v1.2.1 gives *two* MailboxUpdate (one due to the
+		// Unseen count and one due to the Recent count - see lines 413 and 431
+		// in https://github.com/emersion/go-imap/blob/v1.2.1/client/client.go)
+		// and each triggers a LIST-STATUS to the IMAP server, do a crude
+		// deduping mechanism: ignore any MailboxUpdate received less than 20ms
+		// after the last one on the very same worker.
+		if now.After(w.noCheckMailBefore) {
+			w.worker.PostAction(&types.CheckMail{
+				Directories: []string{update.Mailbox.Name},
+			}, nil)
+		} else {
+			w.worker.Debugf("Ignored duplicate MailboxUpdate")
+		}
+		w.noCheckMailBefore = now.Add(20 * time.Millisecond)
 	case *client.MessageUpdate:
 		msg := update.Message
 		if msg.Uid == 0 {
@@ -280,6 +323,15 @@ func (w *IMAPWorker) handleImapUpdate(update client.Update) {
 				msg.Uid = uid
 			}
 		}
+		if w.expunger != nil && w.expunger.IsExpungingForDelete(msg.Uid) {
+			// If we're deleting messages (vs. moving them), after we marked
+			// them as Deleted and before expunging them (i.e. the worker's
+			// ExpungeHandler is not nil), some IMAP servers will send a
+			// MessageUpdate confirming that the messages have been marked as
+			// Deleted. We should simply ignore those to avoid corrupting the
+			// sequence.
+			return
+		}
 		if int(msg.SeqNum) > w.seqMap.Size() {
 			w.seqMap.Put(msg.Uid)
 		}
@@ -291,11 +343,32 @@ func (w *IMAPWorker) handleImapUpdate(update client.Update) {
 				InternalDate:  msg.InternalDate,
 				Uid:           models.Uint32ToUid(msg.Uid),
 			},
+			Unsolicited: true,
 		}, nil)
 	case *client.ExpungeUpdate:
-		if uid, found := w.seqMap.Pop(update.SeqNum); !found {
-			w.worker.Errorf("ExpungeUpdate unknown seqnum: %d", update.SeqNum)
-		} else {
+		// We're notified of a message deletion. There are two cases:
+		//  1. It's linked to a deletion from aerc, hence we have an expunger
+		//     and find the sequence number there => we use the expunger to
+		//     resolve the UID of the deleted message.
+		//  2. Either we don't have an expunger or it does not contain the
+		//     sequence number => we fallback to the actual sequence to resolve
+		//     the UID of the deleted message.
+		use_sequence := false
+		var uid uint32 = 0
+		found := false
+		if w.expunger == nil {
+			use_sequence = true
+		} else if uid, found = w.expunger.PopSequenceNumber(update.SeqNum); !found {
+			use_sequence = true
+		}
+		if use_sequence {
+			uid, found = w.seqMap.Pop(update.SeqNum)
+			if !found {
+				uid = 0
+				w.worker.Errorf("ExpungeUpdate unknown seqnum: %d", update.SeqNum)
+			}
+		}
+		if uid != 0 {
 			w.worker.PostMessage(&types.MessagesDeleted{
 				Uids: []models.UID{models.Uint32ToUid(uid)},
 			}, nil)
@@ -395,3 +468,7 @@ func (w *IMAPWorker) PathSeparator() string {
 	}
 	return w.delimiter
 }
+
+func (w *IMAPWorker) BuildExpungeHandler(uids []uint32, forDelete bool) {
+	w.expunger = NewExpungeHandler(w, uids, forDelete)
+}
