@@ -12,6 +12,7 @@ import (
 	"os/exec"
 	"path/filepath"
 	"runtime"
+	"slices"
 	"sort"
 	"strings"
 	"sync"
@@ -19,6 +20,7 @@ import (
 
 	"github.com/emersion/go-maildir"
 
+	"git.sr.ht/~rjarry/aerc/config"
 	aercLib "git.sr.ht/~rjarry/aerc/lib"
 	"git.sr.ht/~rjarry/aerc/lib/iterator"
 	"git.sr.ht/~rjarry/aerc/lib/log"
@@ -268,13 +270,7 @@ func (w *Worker) getDirectoryInfo(name string) *models.DirectoryInfo {
 				continue
 			}
 		}
-		seen := false
-		for _, flag := range flags {
-			if flag == maildir.FlagSeen {
-				seen = true
-				break
-			}
-		}
+		seen := slices.Contains(flags, maildir.FlagSeen)
 		if !seen {
 			dirInfo.Unseen++
 		}
@@ -498,9 +494,7 @@ func (w *Worker) sort(ctx context.Context, uids []models.UID, criteria []*types.
 	if len(criteria) == 0 {
 		// At least sort by uid, parallel searching can create random
 		// order
-		sort.Slice(uids, func(i int, j int) bool {
-			return uids[i] < uids[j]
-		})
+		slices.Sort(uids)
 		return uids, nil
 	}
 	var msgInfos []*models.MessageInfo
@@ -577,7 +571,8 @@ func (w *Worker) handleFetchDirectoryThreaded(
 func (w *Worker) threads(ctx context.Context, uids []models.UID,
 	criteria []*types.SortCriterion,
 ) ([]*types.Thread, error) {
-	builder := aercLib.NewThreadBuilder(iterator.NewFactory(false), false)
+	ui := config.Ui.ForAccount(w.worker.Name())
+	builder := aercLib.NewThreadBuilder(iterator.NewFactory(ui.ReverseOrder), ui.ThreadingBySubject)
 	msgInfos := make([]*models.MessageInfo, 0, len(uids))
 	mu := sync.Mutex{}
 	wg := sync.WaitGroup{}
@@ -611,9 +606,7 @@ func (w *Worker) threads(ctx context.Context, uids []models.UID,
 	var err error
 	switch {
 	case len(criteria) == 0:
-		sort.Slice(uids, func(i int, j int) bool {
-			return uids[i] < uids[j]
-		})
+		slices.Sort(uids)
 	default:
 		uids, err = lib.Sort(msgInfos, criteria)
 		if err != nil {
@@ -621,7 +614,7 @@ func (w *Worker) threads(ctx context.Context, uids []models.UID,
 			return nil, err
 		}
 	}
-	threads := builder.Threads(uids, false, false)
+	threads := builder.Threads(uids, ui.ReverseThreadOrder, ui.SortThreadSiblings)
 	return threads, nil
 }
 
@@ -912,11 +905,11 @@ func (w *Worker) msgInfoFromUid(uid models.UID) (*models.MessageInfo, error) {
 	if err != nil {
 		return nil, err
 	}
-	name, err := m.dir.Filename(m.key)
+	msg, err := m.dir.MessageByKey(m.key)
 	if err != nil {
 		return nil, err
 	}
-	info.Filenames = []string{name}
+	info.Filenames = []string{msg.Filename()}
 	if w.c.IsRecent(uid) {
 		info.Flags |= models.RecentFlag
 	}
