@@ -164,18 +164,18 @@ func (m *Message) Filename() (string, error) {
 // Consider using *Message.ModifyTags for multiple additions / removals
 // instead of looping over a tag array
 func (m *Message) AddTag(tag string) error {
-	return m.ModifyTags([]string{tag}, nil)
+	return m.ModifyTags([]string{tag}, nil, nil)
 }
 
 // RemoveTag removes a single tag.
 // Consider using *Message.ModifyTags for multiple additions / removals
 // instead of looping over a tag array
 func (m *Message) RemoveTag(tag string) error {
-	return m.ModifyTags(nil, []string{tag})
+	return m.ModifyTags(nil, []string{tag}, nil)
 }
 
-func (m *Message) ModifyTags(add, remove []string) error {
-	return m.db.MsgModifyTags(m.key, add, remove)
+func (m *Message) ModifyTags(add, remove, toggle []string) error {
+	return m.db.MsgModifyTags(m.key, add, remove, toggle)
 }
 
 func (m *Message) Remove(curDir maildir.Dir, mfs types.MultiFileStrategy) error {
@@ -200,15 +200,15 @@ func (m *Message) Copy(curDir, destDir maildir.Dir, mfs types.MultiFileStrategy)
 			return fmt.Errorf("failed to parse message filename: %s", filename)
 		}
 
-		newKey, err := source.Copy(destDir, key)
+		msg, err := source.MessageByKey(key)
 		if err != nil {
-			return err
+			return fmt.Errorf("failed to retrieve %q: %w", key, err)
 		}
-		newFilename, err := destDir.Filename(newKey)
+		msg, err = msg.CopyTo(destDir)
 		if err != nil {
-			return err
+			return fmt.Errorf("failed to copy %q: %w", key, err)
 		}
-		_, err = m.db.IndexFile(newFilename)
+		_, err = m.db.IndexFile(msg.Filename())
 		if err != nil {
 			return err
 		}
