@@ -609,7 +609,7 @@ func (w *worker) handleModifyLabels(msg *types.ModifyLabels) error {
 		if err != nil {
 			return fmt.Errorf("could not get message from uid %s: %w", uid, err)
 		}
-		err = m.ModifyTags(msg.Add, msg.Remove)
+		err = m.ModifyTags(msg.Add, msg.Remove, msg.Toggle)
 		if err != nil {
 			return fmt.Errorf("could not modify message tags: %w", err)
 		}
@@ -920,16 +920,12 @@ func (w *worker) handleAppendMessage(msg *types.AppendMessage) error {
 	if !ok {
 		return fmt.Errorf("Can only create file in a maildir folder")
 	}
-	key, writer, err := dest.Create(lib.ToMaildirFlags(msg.Flags))
+	newMsg, writer, err := dest.Create(lib.ToMaildirFlags(msg.Flags))
 	if err != nil {
 		w.w.Errorf("could not create message at %s: %v", msg.Destination, err)
 		return err
 	}
-	filename, err := dest.Filename(key)
-	if err != nil {
-		writer.Close()
-		return err
-	}
+	filename := newMsg.Filename()
 	if _, err := io.Copy(writer, msg.Reader); err != nil {
 		w.w.Errorf("could not write message to destination: %v", err)
 		writer.Close()
@@ -1021,7 +1017,7 @@ func (w *worker) processNewMaildirFiles(dir string) error {
 			continue
 		}
 		// Force message to move from new/ to cur/
-		err = w.db.MsgModifyTags(key, nil, nil)
+		err = w.db.MsgModifyTags(key, nil, nil, nil)
 		if err != nil {
 			w.w.Errorf("MsgModifyTags failed: %v", err)
 		}
@@ -1045,5 +1041,5 @@ func (w *worker) addFlags(id string, flags models.Flags) error {
 		}
 	}
 
-	return w.db.MsgModifyTags(id, addTags, removeTags)
+	return w.db.MsgModifyTags(id, addTags, removeTags, nil)
 }
